@@ -248,6 +248,6 @@ class TTTH_Analyzer:
             print(f'Variable {numerical_variable} have no outlier')
             return
         else:
-            print(f'variable {numerical_variable} have {round(upper_outlier_ratio)}% upper outlier')
-            print(f'variable {numerical_variable} have {round(lower_outlier_ratio)}% lower outlier')
+            print(f'variable {numerical_variable} have {round(upper_outlier_ratio, 3)}% upper outlier')
+            print(f'variable {numerical_variable} have {round(lower_outlier_ratio, 3)}% lower outlier')
             return index_up, index_low
